Index: chrome/browser/ui/views/bookmarks/bookmark_bar_view.h |
diff --git a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h |
index 2546b17294d9f6a8478f2201a556b2b70546ea5c..4d34eb948815eae30cb7c4122dddf6d81dac19da 100644 |
--- a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h |
+++ b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h |
@@ -306,6 +306,9 @@ class BookmarkBarView : public views::AccessiblePaneView, |
// Creates the button showing the "Managed Bookmarks" folder. |
views::MenuButton* CreateManagedBookmarksButton(); |
+ // Creates the button showing the supervised bookmarks items. |
+ views::MenuButton* CreateSupervisedBookmarksButton(); |
+ |
// Creates the button used when not all bookmark buttons fit. |
views::MenuButton* CreateOverflowButton(); |
@@ -371,8 +374,9 @@ class BookmarkBarView : public views::AccessiblePaneView, |
// Updates the colors for all the child objects in the bookmarks bar. |
void UpdateColors(); |
// Updates the visibility of |other_bookmarks_button_| and |
// |managed_bookmarks_button_|. Also shows or hides the separator if required. |
// Returns true if something changed and a LayoutAndPaint() is needed. |
bool UpdateOtherAndManagedButtonsVisibility(); |
@@ -421,6 +425,9 @@ class BookmarkBarView : public views::AccessiblePaneView, |
// Shows the managed bookmarks entries. |
views::MenuButton* managed_bookmarks_button_; |
+ // Shows the supervised bookmarks entries. |
+ views::MenuButton* supervised_bookmarks_button_; |
+ |
// Shows the Apps page shortcut. |
views::LabelButton* apps_page_shortcut_; |
@@ -371,8 +374,9 @@ class BookmarkBarView : public views::AccessiblePaneView, |
// Updates the colors for all the child objects in the bookmarks bar. |
void UpdateColors(); |
- // Updates the visibility of |other_bookmarks_button_| and |
- // |managed_bookmarks_button_|. Also shows or hides the separator if required. |
+ // Updates the visibility of |other_bookmarks_button_|, |
+ // |managed_bookmarks_button_|, and |supervised_bookmarks_button_|. Also |
+ // shows or hides the separator if required. |
// Returns true if something changed and a LayoutAndPaint() is needed. |
bool UpdateOtherAndManagedButtonsVisibility(); |